==> haskell-vector-binary-instances-0.2.5.2-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-binary-instances
version:              0.2.5.2
visibility:           public
id:                   vector-binary-instances-0.2.5.2-B35LJcM7kDk6ex2gWZqScg
key:                  vector-binary-instances-0.2.5.2-B35LJcM7kDk6ex2gWZqScg
license:              BSD-3-Clause
maintainer:
    dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>

author:               Don Stewart
stability:            Experimental
homepage:             https://github.com/bos/vector-binary-instances
synopsis:             Instances of Data.Binary for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
    .
    Try the cereal-vector package if you are looking for Data.Serialize
    instances.

category:             Data
abi:                  fb88721de176bb7a32d8709ecec2848e
exposed:              True
exposed-modules:      Data.Vector.Binary
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-binary-instances
hs-libraries:         HSvector-binary-instances-0.2.5.2-B35LJcM7kDk6ex2gWZqScg
depends:
    base-4.18.2.1 binary-0.8.9.1 vector-0.13.2.0-6vtrErFI1tV1Z02auPMCSS

haddock-interfaces:
    /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-binary-instances-0.2.5.2-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-binary-instances
version:              0.2.5.2
visibility:           public
id:                   vector-binary-instances-0.2.5.2-Icf3cJJhCgW4lKdS51reKr
key:                  vector-binary-instances-0.2.5.2-Icf3cJJhCgW4lKdS51reKr
license:              BSD-3-Clause
maintainer:
    dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>

author:               Don Stewart
stability:            Experimental
homepage:             https://github.com/bos/vector-binary-instances
synopsis:             Instances of Data.Binary for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
    .
    Try the cereal-vector package if you are looking for Data.Serialize
    instances.

category:             Data
abi:                  ab8f13481d4d77d33fce18b2549eb391
exposed:              True
exposed-modules:      Data.Vector.Binary
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/vector-binary-instances-0.2.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-binary-instances
hs-libraries:         HSvector-binary-instances-0.2.5.2-Icf3cJJhCgW4lKdS51reKr
depends:
    base-4.18.2.1 binary-0.8.9.1 vector-0.13.2.0-3Co1wNPhccp6XnsJEn8cXR

haddock-interfaces:
    /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
